@@ -80,7 +80,7 @@ class GenericOmnibarView(View):
                 d.append({
                     'type': m.get_id(),
                     'handler': 'toDetail',
-                    'param0': o.name,
+                    'param0': o.get_omnibar_ref(),
                     'param1': o.get_absolute_url()
                 })
         return JsonResponse(d, safe=False)
